@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     CodeType,
@@ -186,7 +186,7 @@ _RequiredCreateDataSetRequestRequestTypeDef = TypedDict(
 _OptionalCreateDataSetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDataSetRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -249,7 +249,7 @@ _OptionalCreateRevisionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRevisionRequestRequestTypeDef",
     {
         "Comment": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -374,7 +374,7 @@ class ExportAssetToSignedUrlResponseDetailsTypeDef(
 _RequiredExportAssetsToS3RequestDetailsTypeDef = TypedDict(
     "_RequiredExportAssetsToS3RequestDetailsTypeDef",
     {
-        "AssetDestinations": List["AssetDestinationEntryTypeDef"],
+        "AssetDestinations": Sequence["AssetDestinationEntryTypeDef"],
         "DataSetId": str,
         "RevisionId": str,
     },
@@ -421,7 +421,7 @@ _RequiredExportRevisionsToS3RequestDetailsTypeDef = TypedDict(
     "_RequiredExportRevisionsToS3RequestDetailsTypeDef",
     {
         "DataSetId": str,
-        "RevisionDestinations": List["RevisionDestinationEntryTypeDef"],
+        "RevisionDestinations": Sequence["RevisionDestinationEntryTypeDef"],
     },
 )
 _OptionalExportRevisionsToS3RequestDetailsTypeDef = TypedDict(
@@ -627,7 +627,7 @@ class ImportAssetFromSignedUrlResponseDetailsTypeDef(
 ImportAssetsFromS3RequestDetailsTypeDef = TypedDict(
     "ImportAssetsFromS3RequestDetailsTypeDef",
     {
-        "AssetSources": List["AssetSourceEntryTypeDef"],
+        "AssetSources": Sequence["AssetSourceEntryTypeDef"],
         "DataSetId": str,
         "RevisionId": str,
     },
@@ -927,7 +927,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -935,7 +935,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
